@@ -1,7 +1,7 @@
 # flake8: noqa
 
 from .csv import read_csv, write_csv
-from .excel import read_excel, write_excel
+from .excel import read_excel, write_excel, ExcelWriteBackend
 from .json import table_to_json_data, json_data_to_table
 from .parsers.fixer import ParseFixer
 from .parsers.blocks import parse_blocks
