@@ -1,12 +1,15 @@
 import json
 import os
 from pathlib import Path
+from textwrap import dedent
 
 import pandas as pd
 import pytest
+from pytest import raises
 
 from pdtable import ParseFixer, BlockType
 from pdtable import read_csv
+from pdtable.table_origin import InputError
 from pdtable.io import table_to_json_data
 from pdtable.io.parsers import parse_blocks
 from pdtable.io.parsers.blocks import make_table
@@ -14,7 +17,7 @@ from pdtable.io.parsers.blocks import make_table
 
 class custom_test_fixer(ParseFixer):
     def __init__(self):
-        ParseFixer.__init__(self)
+        super().__init__()
         self.stop_on_errors = False
         self._called_from_test = True
 
@@ -23,6 +26,21 @@ def input_dir() -> Path:
     return Path(__file__).parent / "input/with_errors"
 
 
+def test_displays_all_error_messages():
+    """By default, ParseFixer stops on errors and outputs a message
+    listing all encountered errors."""
+    expected_error_msg = dedent(
+        """\
+        Stopped parsing after 2 errors in table 'farm_cols1' with messages:
+        Duplicate column 'flt' at position 4 in table 'farm_cols1'.
+        Duplicate column 'flt' at position 5 in table 'farm_cols1'."""
+    )
+    with raises(InputError) as input_error:
+        blocks = list(read_csv(input_dir() / "cols1.csv"))
+
+    msg = input_error.value.args[0].issue  # Avoid repr escaping
+    assert expected_error_msg == str(msg)
+
 def test_columns_duplicate():
     """
        Verify that default ParseFixer corrects duplicate column names
@@ -42,24 +60,6 @@ def test_columns_duplicate():
     assert tab.df["flt"][0] == 3.0
 
 
-def test_columns_missing():
-    """
-       Verify that default ParseFixer corrects missing column name
-
-    """
-    tab = None
-    with open(input_dir() / "cols2.csv", "r") as fh:
-        g = read_csv(fh, fixer=custom_test_fixer)
-        for tp, tt in g:
-            if True:
-                if tp == BlockType.TABLE:
-                    tab = tt
-                    break
-    assert tab is not None
-    assert tab.df["missing_fixed_000"] is not None
-    assert tab.df["flt"][6] == 7.11
-
-
 def test_custom_fixer():
     """ Test custom ParseFixer
         Verify that read_csv uses custom ParseFixer
@@ -90,7 +90,7 @@ def test_custom_fixer():
                 assert tt["columns"]["flt"]["values"][0] == 22.0 / 7.0
                 assert tt["columns"]["flt2"]["values"][2] == 22.0 / 7.0
 
-    with pytest.raises(ValueError):
+    with pytest.raises(InputError):
         # test read_csv w. class (not instance) of fixer
         # class has default stop_on_errors = True
         with open(input_dir() / "types3.csv", "r") as fh:
@@ -165,14 +165,14 @@ def test_stop_on_errors():
     fix.stop_on_errors = True
     fix._dbg = False  # ignore during test
     pi = 0
-    with pytest.raises(ValueError):
+    with pytest.raises(InputError):
         for typ, tab in parse_blocks(table_lines, fixer=fix, to="pdtable"):
             if typ != BlockType.TABLE:
                 continue
             assert tab.df["a4"][0] == 3.14
             pi += 1
 
-    with pytest.raises(ValueError):
+    with pytest.raises(InputError):
         for typ, tab in parse_blocks(table_lines, fixer=fix, to="jsondata"):
             if typ != BlockType.TABLE:
                 continue
@@ -216,7 +216,7 @@ def test_stop_on_errors_default_fixer():
     assert tab.name == "tab_ok"
     assert tab.df["a4"][0] == 3.14
 
-    with pytest.raises(ValueError):
+    with pytest.raises(InputError):
         typ, tab = next(g)
         print(f"-oOo-: {typ} {tab}")
 
@@ -240,7 +240,7 @@ def test_stop_on_errors_default_fixer():
     assert tab.name == "tab_ok"
     assert tab.df["a1"][0] == 3.14
 
-    with pytest.raises(ValueError):
+    with pytest.raises(InputError):
         typ, tab = next(g)
         print(f"-oOo-: {typ} {tab}")
 
@@ -267,7 +267,7 @@ def test_stop_on_errors_default_fixer():
     assert tab.df["a1"][1] == 3.14
     assert tab.df["a2"][1] == pd.to_datetime("2020-08-12")
 
-    with pytest.raises(ValueError):
+    with pytest.raises(InputError):
         typ, tab = next(g)
         print(f"-oOo-: {typ} {tab}")
 
